@@ -17,9 +17,11 @@ def dataform_transform(project_id=os.environ.get("DATAFORM_PROJECT_ID"),
 
 @prefect.task
 def data_monitoring(config):
-    return monitoring.run(rules_list=json.loads(config)["rules"])
+    return monitoring.run(rules_list=config["rules"])
 
 def prefect_parameter_read_json(path,param_name):
         return prefect.Parameter(param_name,
-                                 default=utils.local.read_configJSON(path,"string")
-                                 )
\ No newline at end of file
+                                 default=utils.local.read_configJSON(path,"dict")
+                                 )
+
+
